# Config Tools

This package includes tools related to the QOP configuration file.
It currently has the following packages:

* [Helper Tools](README_helper_tools.md) - This package includes tools for writing and updating the configuration. 
* [Integration Weights Tools](README_integration_weights_tools.md) - This package includes tools for the creation and manipulation of integration weights. 
* [Waveform Tools](README_waveform_tools.md) - This package includes tools for creating waveforms useful for experiments with the QOP.
* [Config GUI](README_config_GUI.md) - This package contains a GUI for creating and visualizing the configuration file - No longer being actively developed.
* [Config Builder](README_config_builder.md) - This package contains an API for creating and manipulation configuration files - No longer being actively developed.
